Country class

Constructors

Country({int? id, String? name, String? emoji, String? emojiU, List<Region>? state, String? iso2, String? iso3, String? frenchname, int? countrycode})
Country.fromJson(Map<String, dynamic> json)

Properties

countrycode ↔ int?
getter/setter pair
emoji ↔ String?
getter/setter pair
emojiU ↔ String?
getter/setter pair
frenchname ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
iso2 ↔ String?
getter/setter pair
iso3 ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ List<Region>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited